exceptiontools.TimeSignatureAssignmentError
===========================================

.. abjad-lineage:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError

.. autoclass:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__unicode__
   :noindex:
